package com.nisum.demo.blobStorage;

import com.microsoft.azure.functions.annotation.*;
import com.microsoft.azure.functions.*;
import org.bouncycastle.openpgp.PGPException;
import org.bouncycastle.openpgp.PGPPublicKey;
import org.bouncycastle.openpgp.PGPSecretKey;

import java.io.*;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.SignatureException;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;
import java.util.regex.Pattern;

/**
 * Azure Functions with Azure Blob trigger.
 */
public class BlobTriggerFunction {
    /**
     * This function will be invoked when a new or updated blob is detected at the specified path. The blob contents are provided as input to this function.
     */
    @FunctionName("BlobTriggerFunc")
    public void run(
        @BlobTrigger(name = "file", path = "test/{name}", dataType = "binary", connection = "AzureWebJobsStorage") byte[] content,
        @BindingName("name") String name,
        final ExecutionContext context
    ) throws IOException {
        ResourceBundle resourceBundle = new PropertyResourceBundle(new FileInputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/application.properties"));
        if (Pattern.matches("[a-z|A-Z]*.csv", name)) {
        String directoryPath = resourceBundle.getString("files.directory.path")+name;
        if (!Files.exists(Paths.get(directoryPath))) {
            Files.createFile(Paths.get(directoryPath));
        }

        try (FileOutputStream fileOutputStream = new FileOutputStream(directoryPath, true)) {
                fileOutputStream.write(content);
            }
//        String encryptedFilePath = resourceBundle.getString("files.directory.path")+name;
            OutputStream outbound = new FileOutputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/outbound/eibad.csv");
            String inbound = "/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/inbound/eibad.csv";

            // Writes data to the output stream
            InputStream inputStreamSecretKey = new FileInputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/keys/gappoc.asc");
            InputStream inputStreamPublicKey = new FileInputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/keys/gappocPublic.asc");
            char[] pass = {'n','i','s','u','m','1','2','3','4'};
            try {
//                PGPPublicKey key = PGPUtils.readPublicKey(inputStream);
//                use it when using only public key
//                context.getLogger().info("key : "+ key.isEncryptionKey()+"  "+key.getCreationTime() +"::"+key.toString());

//                PGPSecretKey pgpSecretKey = PGPUtils.readSecretKey(inputStream);
//                use it when using public + private key
//                context.getLogger().info("key : "+ pgpSecretKey.isSigningKey()+"  "+pgpSecretKey.getKeyID() +"::"+pgpSecretKey.toString());
//                context.getLogger().info("----");

//                PGPUtils.encryptAndSignFile(outbound,inbound,inputStreamPublicKey,inputStreamSecretKey,true,true,pass);
//                outbound.close();
//
                context.getLogger().info("---encryptAndSignFile---");

                InputStream outboundIn = new FileInputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/outbound/eibad.csv");
                OutputStream inboundN = new FileOutputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/out/a.csv");
                PGPUtils.decryptFile(outboundIn,inboundN, inputStreamSecretKey,pass,inputStreamPublicKey);
                outboundIn.close();
                inboundN.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
            // Closes the output stream
        }

        context.getLogger().info("Java Blob trigger function processed a blob. Name: " + name + "\n  Size: " + content.length + " Bytes");
    }
}
